@@ -508,7 +508,7 @@ class get(XMLRPCCommand):
     def invoke_remote(self):
         response = self.server.get(self.args.SHA1)
         if self.args.output is None:
-            filename = response['content_filename']
+            filename = self.args.SHA1
             if os.path.exists(filename) and not self.args.overwrite:
                 print >> sys.stderr, "File {filename!r} already exists".format(
                         filename=filename)
